# CHANGELOG

## [0.0.2] - 2022-12-14

- Fix: Fix missing ui and svg files by including them in setuptools build

## [0.0.1] - 2022-12-14

- Initial release: QGIS dock widget for visualizing quality check results
[0.0.1]: https://github.com/nlsfi/quality-result-gui/releases/tag/v0.0.1
[0.0.2]: https://github.com/nlsfi/quality-result-gui/releases/tag/v0.0.2
